@@ -20,38 +20,26 @@
  */
 
 #ifndef DIR_H
-#define DIR_H   1
+#define DIR_H 1
 
 /*
  *  Directions:
  */
 enum Direction {
-    north = 0,
-    northeast = 1,
-    east = 2,
-    southeast = 3,
-    south = 4,
-    southwest = 5,
-    west = 6,
-    northwest = 7
+	north     = 0,
+	northeast = 1,
+	east      = 2,
+	southeast = 3,
+	south     = 4,
+	southwest = 5,
+	west      = 6,
+	northwest = 7
 };
 
-Direction Get_direction_NoWrap(
-    int deltay,
-    int deltax
-);
-Direction Get_direction(
-    int deltay,
-    int deltax
-);
-Direction Get_direction4(
-    int deltay,
-    int deltax
-);
+Direction Get_direction_NoWrap(int deltay, int deltax);
+Direction Get_direction(int deltay, int deltax);
+Direction Get_direction4(int deltay, int deltax);
 
-int Get_direction16(
-    int deltay,
-    int deltax
-);
+int Get_direction16(int deltay, int deltax);
 
 #endif
