@@ -20,8 +20,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define STATS_GUMP_H
 
 #include "Gump.h"
-#include "misc_buttons.h"
 #include "ignore_unused_variable_warning.h"
+#include "misc_buttons.h"
 
 class Actor;
 
@@ -30,28 +30,34 @@ class Actor;
  */
 class Stats_gump : public Gump {
 protected:
-	Actor *get_actor() {
-		return reinterpret_cast<Actor *>(container);
+	Actor* get_actor() {
+		return reinterpret_cast<Actor*>(container);
 	}
-	static short textx;     // X-coord. of where to write.
-	static short texty[10];     // Y-coords.
+
+	static short textx;        // X-coord. of where to write.
+	static short texty[10];    // Y-coords.
 
 public:
-	Stats_gump(Container_game_object *cont, int initx, int inity);
-	Stats_gump(Container_game_object *cont, int initx, int inity,
-	           int shnum, ShapeFile shfile);
-	static Stats_gump *create(Game_object *npc_obj, int x, int y);
+	Stats_gump(Container_game_object* cont, int initx, int inity);
+	Stats_gump(
+			Container_game_object* cont, int initx, int inity, int shnum,
+			ShapeFile shfile);
+	static Stats_gump* create(Game_object* npc_obj, int x, int y);
+
 	// Add object.
-	bool add(Game_object *obj, int mx = -1, int my = -1,
-	                int sx = -1, int sy = -1, bool dont_check = false,
-	                bool combine = false) override {
-		ignore_unused_variable_warning(obj, mx, my, sx, sy, dont_check, combine);
+	bool add(
+			Game_object* obj, int mx = -1, int my = -1, int sx = -1,
+			int sy = -1, bool dont_check = false,
+			bool combine = false) override {
+		ignore_unused_variable_warning(
+				obj, mx, my, sx, sy, dont_check, combine);
 		return false;    // Can't drop onto it.
 	}
+
 	// Paint it and its contents.
 	void paint() override;
 
-	Game_object *find_object(int mx, int my) override {
+	Game_object* find_object(int mx, int my) override {
 		ignore_unused_variable_warning(mx, my);
 		return nullptr;
 	}
