@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2000-2022 The Exult Team
+Copyright (C) 2000-2024 The Exult Team
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -28,12 +28,15 @@ class Actor;
  */
 class Checkmark_button : public Gump_button {
 public:
-	Checkmark_button(Gump *par, int px, int py);
-	Gump_widget *clone(Gump *par) override {
+	Checkmark_button(Gump* par, int px, int py);
+
+	Gump_widget* clone(Gump* par) override {
 		return new Checkmark_button(par, x, y);
 	}
+
 	// What to do when 'clicked':
-	bool activate(int button = 1) override;
+	bool activate(MouseButton button) override;
+
 	bool is_checkmark() const override {
 		return true;
 	}
@@ -44,12 +47,14 @@ public:
  */
 class Heart_button : public Gump_button {
 public:
-	Heart_button(Gump *par, int px, int py);
-	Gump_widget *clone(Gump *par) override {
+	Heart_button(Gump* par, int px, int py);
+
+	Gump_widget* clone(Gump* par) override {
 		return new Heart_button(par, x, y);
 	}
+
 	// What to do when 'clicked':
-	bool activate(int button = 1) override;
+	bool activate(MouseButton button) override;
 };
 
 /*
@@ -57,12 +62,14 @@ public:
  */
 class Disk_button : public Gump_button {
 public:
-	Disk_button(Gump *par, int px, int py);
-	Gump_widget *clone(Gump *par) override {
+	Disk_button(Gump* par, int px, int py);
+
+	Gump_widget* clone(Gump* par) override {
 		return new Disk_button(par, x, y);
 	}
+
 	// What to do when 'clicked':
-	bool activate(int button = 1) override;
+	bool activate(MouseButton button) override;
 };
 
 /*
@@ -70,12 +77,14 @@ public:
  */
 class Combat_button : public Gump_button {
 public:
-	Combat_button(Gump *par, int px, int py);
-	Gump_widget *clone(Gump *par) override {
+	Combat_button(Gump* par, int px, int py);
+
+	Gump_widget* clone(Gump* par) override {
 		return new Combat_button(par, x, y);
 	}
+
 	// What to do when 'clicked':
-	bool activate(int button = 1) override;
+	bool activate(MouseButton button) override;
 	void paint() override;
 };
 
@@ -83,28 +92,32 @@ public:
  *  The halo button.
  */
 class Halo_button : public Gump_button {
-	Actor *actor;           // Who this represents.
+	Actor* actor;    // Who this represents.
 public:
-	Halo_button(Gump *par, int px, int py, Actor *a);
-	Gump_widget *clone(Gump *par) override {
+	Halo_button(Gump* par, int px, int py, Actor* a);
+
+	Gump_widget* clone(Gump* par) override {
 		return new Halo_button(par, x, y, actor);
 	}
+
 	// What to do when 'clicked':
-	bool activate(int button = 1) override;
+	bool activate(MouseButton button) override;
 };
 
 /*
  *  Combat mode.  Has 10 frames corresponding to Actor::Attack_mode.
  */
 class Combat_mode_button : public Gump_button {
-	Actor *actor;           // Who this represents.
+	Actor* actor;    // Who this represents.
 public:
-	Combat_mode_button(Gump *par, int px, int py, Actor *a);
-	Gump_widget *clone(Gump *par) override {
+	Combat_mode_button(Gump* par, int px, int py, Actor* a);
+
+	Gump_widget* clone(Gump* par) override {
 		return new Combat_mode_button(par, x, y, actor);
 	}
+
 	// What to do when 'clicked':
-	bool activate(int button = 1) override;
+	bool activate(MouseButton button) override;
 };
 
 /*
@@ -112,14 +125,14 @@ public:
  */
 class Cstats_button : public Gump_button {
 public:
-	Cstats_button(Gump *par, int px, int py);
-	Gump_widget *clone(Gump *par) override {
+	Cstats_button(Gump* par, int px, int py);
+
+	Gump_widget* clone(Gump* par) override {
 		return new Cstats_button(par, x, y);
 	}
 
 	// What to do when 'clicked':
-	bool activate(int button = 1) override;
+	bool activate(MouseButton button) override;
 };
 
 #endif
-
