@@ -24,35 +24,47 @@ Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA  02111-1307, USA.
 */
 
-
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#	include <config.h>
 #endif
 
-#include <cstring>
+#ifdef __GNUC__
+#	pragma GCC diagnostic push
+#	pragma GCC diagnostic ignored "-Wold-style-cast"
+#	pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#endif    // __GNUC__
+#include <SDL.h>
+#ifdef __GNUC__
+#	pragma GCC diagnostic pop
+#endif    // __GNUC__
 
-#include "SDL_video.h"
-#include "iwin8.h"
 #include "common_types.h"
 #include "gamma.h"
-#include <climits>
+#include "iwin8.h"
+
 #include <algorithm>
+#include <climits>
+#include <cstring>
+
+using std::make_unique;
 using std::rotate;
 using std::unique_ptr;
-using std::make_unique;
 
 GammaTable<uint8> Image_window8::GammaRed(256);
 GammaTable<uint8> Image_window8::GammaBlue(256);
 GammaTable<uint8> Image_window8::GammaGreen(256);
 
-Image_window8::Image_window8(unsigned int w, unsigned int h, unsigned int gwidth, unsigned int gheight,
-                             int scl, bool fs, int sclr, Image_window::FillMode fillmode, unsigned int fillsclr)
-	: Image_window(new Image_buffer8(0, 0, nullptr), w, h, gwidth, gheight,
-	               scl, fs, sclr, fillmode, fillsclr) {
-	ib8 = static_cast<Image_buffer8 *>(ibuf);
+Image_window8::Image_window8(
+		unsigned int w, unsigned int h, unsigned int gwidth,
+		unsigned int gheight, int scl, bool fs, int sclr,
+		Image_window::FillMode fillmode, unsigned int fillsclr)
+		: Image_window(
+				  new Image_buffer8(0, 0, nullptr), w, h, gwidth, gheight, scl,
+				  fs, sclr, fillmode, fillsclr) {
+	ib8 = static_cast<Image_buffer8*>(ibuf);
 }
 
-void Image_window8::get_gamma(double &r, double &g, double &b) {
+void Image_window8::get_gamma(double& r, double& g, double& b) {
 	r = GammaRed.get_gamma();
 	g = GammaGreen.get_gamma();
 	b = GammaBlue.get_gamma();
@@ -69,11 +81,11 @@ void Image_window8::set_gamma(double r, double g, double b) {
  */
 
 inline unsigned char Get_color8(
-    unsigned char val,
-    int maxval,
-    int brightness          // 100=normal.
+		unsigned char val, int maxval,
+		int brightness    // 100=normal.
 ) {
-	uint32 c = (static_cast<uint32>(val) * brightness * 255L) / (100 * maxval);
+	const uint32 c
+			= (static_cast<uint32>(val) * brightness * 255L) / (100 * maxval);
 	return c <= 255L ? static_cast<unsigned char>(c) : 255;
 }
 
@@ -82,21 +94,25 @@ inline unsigned char Get_color8(
  */
 
 void Image_window8::set_palette(
-    const unsigned char *rgbs,        // 256 3-byte entries.
-    int maxval,         // Highest val. for each color.
-    int brightness          // Brightness control (100 = normal).
+		const unsigned char* rgbs,         // 256 3-byte entries.
+		int                  maxval,       // Highest val. for each color.
+		int                  brightness    // Brightness control (100 = normal).
 ) {
 	// Get the colors.
 	SDL_Color colors2[256];
 	for (int i = 0; i < 256; i++) {
-		colors2[i].r = colors[i * 3] = GammaRed[Get_color8(rgbs[3 * i], maxval, brightness)];
-		colors2[i].g = colors[i * 3 + 1]  = GammaGreen[Get_color8(rgbs[3 * i + 1], maxval, brightness)];
-		colors2[i].b = colors[i * 3 + 2]  = GammaBlue[Get_color8(rgbs[3 * i + 2], maxval, brightness)];
+		colors2[i].r = colors[i * 3]
+				= GammaRed[Get_color8(rgbs[3 * i], maxval, brightness)];
+		colors2[i].g = colors[i * 3 + 1]
+				= GammaGreen[Get_color8(rgbs[3 * i + 1], maxval, brightness)];
+		colors2[i].b = colors[i * 3 + 2]
+				= GammaBlue[Get_color8(rgbs[3 * i + 2], maxval, brightness)];
 	}
 	SDL_SetPaletteColors(paletted_surface->format->palette, colors2, 0, 256);
 
-	if (paletted_surface != draw_surface)
+	if (paletted_surface != draw_surface) {
 		SDL_SetPaletteColors(draw_surface->format->palette, colors2, 0, 256);
+	}
 }
 
 /*
@@ -104,15 +120,15 @@ void Image_window8::set_palette(
  */
 
 void Image_window8::rotate_colors(
-    int first,          // Palette index of 1st.
-    int num,            // # in range.
-    int upd             // 1 to update hardware palette.
+		int first,    // Palette index of 1st.
+		int num,      // # in range.
+		int upd       // 1 to update hardware palette.
 ) {
 	first *= 3;
 	num *= 3;
-	int cnt = abs(num);
-	unsigned char  *start = colors + first;
-	unsigned char  *finish = start + cnt;
+	const int      cnt    = abs(num);
+	unsigned char* start  = colors + first;
+	unsigned char* finish = start + cnt;
 	if (num > 0) {
 		// Shift upward.
 		rotate(start, finish - 3, finish);
@@ -121,17 +137,20 @@ void Image_window8::rotate_colors(
 		rotate(start, start + 3, finish);
 	}
 
-	if (upd) {          // Take effect now?
+	if (upd) {    // Take effect now?
 		SDL_Color colors2[256];
 		for (int i = 0; i < 256; i++) {
 			colors2[i].r = colors[i * 3];
 			colors2[i].g = colors[i * 3 + 1];
 			colors2[i].b = colors[i * 3 + 2];
 		}
-		SDL_SetPaletteColors(paletted_surface->format->palette, colors2, 0, 256);
+		SDL_SetPaletteColors(
+				paletted_surface->format->palette, colors2, 0, 256);
 
-		if (paletted_surface != draw_surface)
-			SDL_SetPaletteColors(draw_surface->format->palette, colors2, 0, 256);
+		if (paletted_surface != draw_surface) {
+			SDL_SetPaletteColors(
+					draw_surface->format->palette, colors2, 0, 256);
+		}
 	}
 }
 
@@ -139,51 +158,54 @@ static inline int pow2(int x) {
 	return x * x;
 }
 
-//a nearest-average-colour 1/3 scaler
+// a nearest-average-colour 1/3 scaler
 unique_ptr<unsigned char[]> Image_window8::mini_screenshot() {
 	int i;
 	if (!paletted_surface) {
 		return nullptr;
 	}
 
-	auto buf = make_unique<Uint8[]>(96 * 60);
-	const int w = 3 * 96;
-	const int h = 3 * 60;
-	const unsigned char *pixels = ibuf->get_bits();
-	int pitch = ibuf->get_line_width();
+	auto                 buf    = make_unique<Uint8[]>(96 * 60);
+	const int            w      = 3 * 96;
+	const int            h      = 3 * 60;
+	const unsigned char* pixels = ibuf->get_bits();
+	const int            pitch  = ibuf->get_line_width();
 
-	for (int y = 0; y < h; y += 3)
+	for (int y = 0; y < h; y += 3) {
 		for (int x = 0; x < w; x += 3) {
-			//calculate average colour
+			// calculate average colour
 			int r = 0;
 			int g = 0;
 			int b = 0;
-			for (i = 0; i < 3; i++)
+			for (i = 0; i < 3; i++) {
 				for (int j = 0; j < 3; j++) {
-					int pix = pixels[pitch * (j + y + (get_game_height() - h) / 2) +
-					                 i + x + (get_game_width()  - w) / 2 ];
+					const int pix = pixels
+							[pitch * (j + y + (get_game_height() - h) / 2) + i
+							 + x + (get_game_width() - w) / 2];
 					r += colors[3 * pix + 0];
 					g += colors[3 * pix + 1];
 					b += colors[3 * pix + 2];
 				}
+			}
 			r = r / 9;
 			g = g / 9;
 			b = b / 9;
 
-			//find nearest-colour in non-rotating palette
-			int bestdist = INT_MAX;
+			// find nearest-colour in non-rotating palette
+			int bestdist  = INT_MAX;
 			int bestindex = -1;
 			for (i = 0; i < 224; i++) {
-				int dist = pow2(colors[3 * i + 0] - r)
-				           + pow2(colors[3 * i + 1] - g)
-				           + pow2(colors[3 * i + 2] - b);
+				const int dist = pow2(colors[3 * i + 0] - r)
+								 + pow2(colors[3 * i + 1] - g)
+								 + pow2(colors[3 * i + 2] - b);
 				if (dist < bestdist) {
-					bestdist = dist;
+					bestdist  = dist;
 					bestindex = i;
 				}
 			}
 			buf[y * w / 9 + x / 3] = bestindex;
 		}
+	}
 
 	return buf;
 }
