@@ -24,30 +24,36 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifndef INCL_ANIMATE
-#define INCL_ANIMATE    1
+#define INCL_ANIMATE 1
 
 #include "iregobjs.h"
 #include "miscinf.h"
 
+#include <array>
+
 /*
  *  A class for playing sound effects that get updated by position
  *  and distance. Adds itself to time-queue, deletes itself when done.
  */
 class Object_sfx : public Time_sensitive, public Game_singletons {
-	Game_object_weak obj;   // Object that caused the sound.
-	Tile_coord last_pos;
-	int sfx;            // ID of sound effect being played.
-	int channel;        // Channel of sfx being played.
-	void stop_playing();
-	Object_sfx(Game_object *o, int sfx);
+	Game_object_weak obj;    // Object that caused the sound.
+	Tile_coord       last_pos;
+	int              sfx;        // ID of sound effect being played.
+	int              channel;    // Channel of sfx being played.
+	void             stop_playing();
+	Object_sfx(Game_object* o, int sfx);
+
 protected:
 	void dequeue() override;
+
 public:
-	static void Play(Game_object *o, int sfx, int delay = 20);
-	void stop();
+	static void Play(Game_object* o, int sfx, int delay = 20);
+	void        stop();
+
 	int get_sfxnum() {
 		return sfx;
 	}
+
 	void handle_event(unsigned long time, uintptr udata) override;
 };
 
@@ -55,30 +61,33 @@ public:
  *  A class for playing sound effects when certain objects are nearby.
  */
 class Shape_sfx : public Game_singletons {
-	const Game_object *obj;       // Object that caused the sound.
-	const SFX_info *sfxinf;
-	int channel[2];         // ID of sound effect being played.
-	int distance;           // Distance in tiles from Avatar.
-	int dir;            // Direction (0-15) from Avatar.
-	int last_sfx;       // For playing sequential sfx ranges.
-	bool looping;       // If the SFX should loop until stopped.
+	const Game_object* obj;    // Object that caused the sound.
+	const SFX_info*    sfxinf;
+	std::array<int, 2> channel;     // ID of sound effect being played.
+	int                distance;    // Distance in tiles from Avatar.
+	int                dir;         // Direction (0-15) from Avatar.
+	int                last_sfx;    // For playing sequential sfx ranges.
+	bool               looping;     // If the SFX should loop until stopped.
 public:
 	// Create & start playing sound.
-	Shape_sfx(Game_object *o)
-		: obj(o), distance(0), last_sfx(-1) {
-		channel[0] = channel[1] = -1;
+	Shape_sfx(Game_object* o)
+			: obj(o), channel{-1, -1}, distance(0), last_sfx(-1) {
 		sfxinf = obj->get_info().get_sfx_info();
-		if (sfxinf)
+		if (sfxinf) {
 			last_sfx = 0;
-		set_looping();  // To avoid including sfxinf.h.
+		}
+		set_looping();    // To avoid including sfxinf.h.
 	}
+
 	int get_sfxnum() {
 		return last_sfx;
 	}
+
 	int get_distance() {
 		return distance;
 	}
-	void update(bool play); // Set to new object.
+
+	void update(bool play);    // Set to new object.
 	void set_looping();
 	void stop();
 };
@@ -88,57 +97,66 @@ public:
  */
 class Animator : public Time_sensitive, public Game_singletons {
 protected:
-	Game_object *obj;       // Object we're controlling.
-	unsigned char deltax, deltay;   // If wiggling, deltas from
+	Game_object*  obj;               // Object we're controlling.
+	unsigned char deltax, deltay;    // If wiggling, deltas from
 	//   original position.
-	bool animating;         // 1 if animation turned on.
-	Shape_sfx *objsfx;
-	void start_animation();
+	bool       animating;    // 1 if animation turned on.
+	Shape_sfx* objsfx;
+	void       start_animation();
+
 public:
-	Animator(Game_object *o)
-		: obj(o), deltax(0), deltay(0), animating(false) {
+	Animator(Game_object* o) : obj(o), deltax(0), deltay(0), animating(false) {
 		objsfx = new Shape_sfx(obj);
 	}
-	static Animator *create(Game_object *ob);
+
+	static Animator* create(Game_object* ob);
 	~Animator() override;
-	void want_animation() {     // Want animation on.
-		if (!animating)
+
+	void want_animation() {    // Want animation on.
+		if (!animating) {
 			start_animation();
+		}
 	}
+
 	void stop_animation() {
 		animating = false;
 	}
+
 	int get_deltax() {
 		return deltax;
 	}
+
 	int get_deltay() {
 		return deltay;
 	}
+
 	virtual int get_framenum();
-	virtual void activate_animator() {
-	}
-	virtual void deactivate_animator() {
-	}
+
+	virtual void activate_animator() {}
+
+	virtual void deactivate_animator() {}
 };
 
 /*
  *  Animate by going through frames.
  */
 class Frame_animator : public Animator {
-	const Animation_info *aniinf;
-	unsigned short first_frame; // Initial frame of animation cycle
-	unsigned short currpos;         // Current position in the animation.
-	unsigned short nframes;     // Number of frames in cycle.
-	unsigned short frame_counter;       // When to increase frame.
-	unsigned int created;       // Time created
-	unsigned short last_shape;  // To check if we need to re init
-	unsigned short last_frame;  // To check if we need to re init
-	void Initialize();
+	const Animation_info* aniinf;
+	unsigned short        first_frame;    // Initial frame of animation cycle
+	unsigned short        currpos;        // Current position in the animation.
+	unsigned short        nframes;        // Number of frames in cycle.
+	unsigned short        frame_counter;    // When to increase frame.
+	unsigned int          created;          // Time created
+	unsigned short        last_shape;       // To check if we need to re init
+	unsigned short        last_frame;       // To check if we need to re init
+	void                  Initialize();
+
 public:
-	Frame_animator(Game_object *o);
+	Frame_animator(Game_object* o);
 	int get_next_frame();
 	// For Time_sensitive:
 	void handle_event(unsigned long time, uintptr udata) override;
+
 	int get_framenum() override {
 		return obj->get_framenum();
 	}
@@ -149,7 +167,7 @@ public:
  */
 class Sfx_animator : public Animator {
 public:
-	Sfx_animator(Game_object *o);
+	Sfx_animator(Game_object* o);
 	// For Time_sensitive:
 	void handle_event(unsigned long time, uintptr udata) override;
 };
@@ -158,15 +176,17 @@ public:
  *  Animate by going through frames, but only do the lower frames once.
  */
 class Field_frame_animator : public Frame_animator {
-	bool activated;         // Time to check for damage.
+	bool activated;    // Time to check for damage.
 public:
 	friend class Field_object;
-	Field_frame_animator(Game_object *o);
+	Field_frame_animator(Game_object* o);
 	// For Time_sensitive:
 	void handle_event(unsigned long time, uintptr udata) override;
+
 	void activate_animator() override {
 		activated = true;
 	}
+
 	void deactivate_animator() override {
 		activated = false;
 	}
@@ -177,8 +197,8 @@ public:
  */
 class Wiggle_animator : public Animator {
 public:
-	Wiggle_animator(Game_object *o) : Animator(o)
-	{  }
+	Wiggle_animator(Game_object* o) : Animator(o) {}
+
 	// For Time_sensitive:
 	void handle_event(unsigned long time, uintptr udata) override;
 };
@@ -188,19 +208,21 @@ public:
  *  frame.  The base class is for those in U7chunks.
  */
 class Animated_object : public Terrain_game_object {
-	Animator *animator;     // Controls animation.
+	Animator* animator;    // Controls animation.
 public:
-	Animated_object(int shapenum, int framenum, unsigned int tilex,
-	                unsigned int tiley, unsigned int lft = 0);
+	Animated_object(
+			int shapenum, int framenum, unsigned int tilex, unsigned int tiley,
+			unsigned int lft = 0);
 	~Animated_object() override;
 	// Render.
 	void paint() override;
+
 	// +++++Needed on this one:
 	// Get coord. where this was placed.
 	Tile_coord get_original_tile_coord() const override {
-		return get_tile() +
-		       Tile_coord(-animator->get_deltax(),
-		                  -animator->get_deltay(), 0);
+		return get_tile()
+			   + Tile_coord(
+					   -animator->get_deltax(), -animator->get_deltay(), 0);
 	}
 };
 
@@ -209,22 +231,24 @@ public:
  *  frame.  This is the IREG version.
  */
 class Animated_ireg_object : public Ireg_game_object {
-	Animator *animator;     // Controls animation.
+	Animator* animator;    // Controls animation.
 public:
-	Animated_ireg_object(int shapenum, int framenum, unsigned int tilex,
-	                     unsigned int tiley, unsigned int lft = 0);
+	Animated_ireg_object(
+			int shapenum, int framenum, unsigned int tilex, unsigned int tiley,
+			unsigned int lft = 0);
 	~Animated_ireg_object() override;
 	// Render.
 	void paint() override;
+
 	// Get coord. where this was placed.
 	Tile_coord get_original_tile_coord() const override {
-		return get_tile() +
-		       Tile_coord(-animator->get_deltax(),
-		                  -animator->get_deltay(), 0);
+		return get_tile()
+			   + Tile_coord(
+					   -animator->get_deltax(), -animator->get_deltay(), 0);
 	}
 
 	// Write out to IREG file.
-	void write_ireg(ODataSource *out) override;
+	void write_ireg(ODataSource* out) override;
 };
 
 /*
@@ -232,22 +256,22 @@ public:
  *  frame.  This is the IFIX version.
  */
 class Animated_ifix_object : public Ifix_game_object {
-	Animator *animator;     // Controls animation.
+	Animator* animator;    // Controls animation.
 public:
-	Animated_ifix_object(int shapenum, int framenum, unsigned int tilex,
-	                     unsigned int tiley, unsigned int lft = 0);
+	Animated_ifix_object(
+			int shapenum, int framenum, unsigned int tilex, unsigned int tiley,
+			unsigned int lft = 0);
 	~Animated_ifix_object() override;
 	// Render.
 	void paint() override;
+
 	// Get coord. where this was placed.
 	Tile_coord get_original_tile_coord() const override {
-		return get_tile() +
-		       Tile_coord(-animator->get_deltax(),
-		                  -animator->get_deltay(), 0);
+		return get_tile()
+			   + Tile_coord(
+					   -animator->get_deltax(), -animator->get_deltay(), 0);
 	}
 
-	void write_ifix(ODataSource *ifix, bool v2) override;
+	void write_ifix(ODataSource* ifix, bool v2) override;
 };
 #endif
-
-
