@@ -23,12 +23,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifndef INCL_ORDINFO
-#define INCL_ORDINFO    1
+#define INCL_ORDINFO 1
 
-#include "ignore_unused_variable_warning.h"
-
-#include "objs.h"
 #include "gamewin.h"
+#include "ignore_unused_variable_warning.h"
+#include "objs.h"
 #include "shapeinf.h"
 
 /*
@@ -36,40 +35,42 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 class Ordering_info {
 public:
-	TileRect area;         // Area (pixels) rel. to screen.
-	const Shape_info &info;       // Info. about shape.
-	int tx, ty, tz;         // Absolute tile coords.
-	int xs, ys, zs;         // Tile dimensions.
-	int xleft, xright, ynear, yfar, zbot, ztop;
+	TileRect          area;          // Area (pixels) rel. to screen.
+	const Shape_info& info;          // Info. about shape.
+	int               tx, ty, tz;    // Absolute tile coords.
+	int               xs, ys, zs;    // Tile dimensions.
+	int               xleft, xright, ynear, yfar, zbot, ztop;
+
 private:
-	void init(const Game_object *obj) {
-		Tile_coord t = obj->get_tile();
-		tx = t.tx;
-		ty = t.ty;
-		tz = t.tz;
-		int frnum = obj->get_framenum();
-		xs = info.get_3d_xtiles(frnum);
-		ys = info.get_3d_ytiles(frnum);
-		zs = info.get_3d_height();
-		xleft = tx - xs + 1;
-		xright = tx;
-		yfar = ty - ys + 1;
-		ynear = ty;
-		ztop = tz + zs - 1;
-		zbot = tz;
-		if (!zs)        // Flat?
+	void init(const Game_object* obj) {
+		const Tile_coord t = obj->get_tile();
+		tx                 = t.tx;
+		ty                 = t.ty;
+		tz                 = t.tz;
+		const int frnum    = obj->get_framenum();
+		xs                 = info.get_3d_xtiles(frnum);
+		ys                 = info.get_3d_ytiles(frnum);
+		zs                 = info.get_3d_height();
+		xleft              = tx - xs + 1;
+		xright             = tx;
+		yfar               = ty - ys + 1;
+		ynear              = ty;
+		ztop               = tz + zs - 1;
+		zbot               = tz;
+		if (!zs) {    // Flat?
 			zbot--;
+		}
 	}
+
 public:
 	// Create from scratch.
-	Ordering_info(const Game_window *gwin, const Game_object *obj)
-		: area(gwin->get_shape_rect(obj)),
-		  info(obj->get_info()) {
+	Ordering_info(const Game_window* gwin, const Game_object* obj)
+			: area(gwin->get_shape_rect(obj)), info(obj->get_info()) {
 		init(obj);
 	}
-	Ordering_info(const Game_window *gwin, const Game_object *obj, TileRect &a)
-		: area(a),
-		  info(obj->get_info()) {
+
+	Ordering_info(const Game_window* gwin, const Game_object* obj, TileRect& a)
+			: area(a), info(obj->get_info()) {
 		ignore_unused_variable_warning(gwin);
 		init(obj);
 	}
