@@ -24,88 +24,98 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#	include <config.h>
 #endif
 
-// #include <iomanip>           /* Debugging */
+#include "items.h"
+
+#include "databuf.h"
+#include "exult_flx.h"
+#include "fnames.h"
+#include "msgfile.h"
+#include "utils.h"
+
 #include <fstream>
+#include <iostream>
 #include <sstream>
 #include <string>
 #include <vector>
-#include "items.h"
-#include "utils.h"
-#include "msgfile.h"
-#include "fnames.h"
-#include "exult_flx.h"
-#include "data_utils.h"
 
-using std::istream;
-using std::ostream;
-using std::ifstream;
-using std::ofstream;
-using std::stringstream;
 using std::cerr;
 using std::endl;
+using std::ifstream;
+using std::istream;
+using std::ofstream;
+using std::ostream;
 using std::string;
+using std::stringstream;
 using std::vector;
 
-vector<string> item_names;          // Names of U7 items.
-vector<string> text_msgs;           // Msgs. (0x400 - in text.flx).
-vector<string> misc_names;          // Frames, etc (0x500 - 0x5ff/0x685 (BG/SI) in text.flx).
+// Names of U7 items.
+vector<string> item_names;
+// Msgs. (0x400 - in text.flx).
+vector<string> text_msgs;
+// Frames, etc (0x500 - 0x5ff/0x685 (BG/SI) in text.flx).
+vector<string> misc_names;
 
 static inline int remap_index(bool remap, int index, bool sibeta) {
-	if (!remap)
+	if (!remap) {
 		return index;
+	}
 	if (sibeta) {
 		// Account for differences between SI Beta and SI Final when remapping
 		// to SS indices.
-		if (index >= 0x146)
+		if (index >= 0x146) {
 			return index + 17;
-		else if (index >= 0x135)
+		} else if (index >= 0x135) {
 			return index + 16;
-		else if (index >= 0x0f6)
+		} else if (index >= 0x0f6) {
 			return index + 15;
-		else if (index >= 0x0ea)
+		} else if (index >= 0x0ea) {
 			return index + 14;
-		else if (index >= 0x0e5)
+		} else if (index >= 0x0e5) {
 			return index + 13;
-		else if (index >= 0x0b1)
+		} else if (index >= 0x0b1) {
 			return index + 11;
-		else if (index >= 0x0ae)
+		} else if (index >= 0x0ae) {
 			return index + 10;
-		else if (index >= 0x0a2)
+		} else if (index >= 0x0a2) {
 			return index + 9;
-		else if (index >= 0x094)
+		} else if (index >= 0x094) {
 			return index + 8;
-		else if (index >= 0x08b)
+		} else if (index >= 0x08b) {
 			return index + 7;
-		else if (index >= 0x07f)
+		} else if (index >= 0x07f) {
 			return index + 2;
-		else
+		} else {
 			return index;
+		}
 	} else {
-		if (index >= 0x0fa)
+		if (index >= 0x0fa) {
 			return index + 11;
-		else if (index >= 0x0b2)
+		} else if (index >= 0x0b2) {
 			return index + 10;
-		else if (index >= 0x0af)
+		} else if (index >= 0x0af) {
 			return index + 9;
-		else if (index >= 0x094)
+		} else if (index >= 0x094) {
 			return index + 8;
-		else if (index >= 0x08b)
+		} else if (index >= 0x08b) {
 			return index + 7;
-		else if (index >= 0x07f)
+		} else if (index >= 0x07f) {
 			return index + 2;
-		else
+		} else {
 			return index;
+		}
 	}
 }
 
-static inline char const *get_text_internal(vector<string> const &src, unsigned num) {
+static inline const char* get_text_internal(
+		const vector<string>& src, unsigned num) {
 	return src[num].c_str();
 }
 
-static inline void add_text_internal(vector<string> &src, unsigned num, char const *name) {
+static inline void add_text_internal(
+		vector<string>& src, unsigned num, const char* name) {
 	if (num >= src.size()) {
 		src.resize(num + 1);
 	}
@@ -123,14 +133,14 @@ int get_num_item_names() {
 /*
  *  Get an item name.
  */
-char const *get_item_name(unsigned num) {
+const char* get_item_name(unsigned num) {
 	return get_text_internal(item_names, num);
 }
 
 /*
  *  Create an item name.
  */
-void Set_item_name(unsigned num, char const *name) {
+void Set_item_name(unsigned num, const char* name) {
 	add_text_internal(item_names, num, name);
 }
 
@@ -145,14 +155,14 @@ int get_num_text_msgs() {
 /*
  *  Get a text message.
  */
-char const *get_text_msg(unsigned num) {
+const char* get_text_msg(unsigned num) {
 	return get_text_internal(text_msgs, num);
 }
 
 /*
  *  Create a text message.
  */
-void Set_text_msg(unsigned num, char const *msg) {
+void Set_text_msg(unsigned num, const char* msg) {
 	add_text_internal(text_msgs, num, msg);
 }
 
@@ -167,14 +177,14 @@ int get_num_misc_names() {
 /*
  *  Get a misc name.
  */
-char const *get_misc_name(unsigned num) {
+const char* get_misc_name(unsigned num) {
 	return get_text_internal(misc_names, num);
 }
 
 /*
  *  Create a misc name.
  */
-void Set_misc_name(unsigned num, char const *name) {
+void Set_misc_name(unsigned num, const char* name) {
 	add_text_internal(misc_names, num, name);
 }
 
@@ -186,92 +196,95 @@ void Set_misc_name(unsigned num, char const *name) {
  */
 
 static void Setup_item_names(
-    istream &items,
-    istream &msgs,
-    bool si,
-    bool expansion,
-    bool sibeta
-) {
+		IDataSource& items, IDataSource& msgs, bool si, bool expansion,
+		bool sibeta) {
 	vector<string> msglist;
-	int first_msg;          // First in exultmsg.txt.  Should
+	int            first_msg;    // First in exultmsg.txt.  Should
 	//   follow those in text.flx.
-	int total_msgs = 0;
+	int total_msgs     = 0;
 	int num_item_names = 0;
-	int num_text_msgs = 0;
+	int num_text_msgs  = 0;
 	int num_misc_names = 0;
 
-	items.seekg(0x54);
-	int flxcnt = Read4(items);
+	items.seek(0x54);
+	int flxcnt = items.read4();
 	first_msg = num_item_names = flxcnt;
 	if (flxcnt > 0x400) {
 		num_item_names = 0x400;
-		num_text_msgs = flxcnt - 0x400;
+		num_text_msgs  = flxcnt - 0x400;
 		if (flxcnt > 0x500) {
-			num_text_msgs = 0x100;
+			num_text_msgs  = 0x100;
 			num_misc_names = flxcnt - 0x500;
-			int last_name; // Discard all starting from this.
-			if (si)
+			int last_name;    // Discard all starting from this.
+			if (si) {
 				last_name = 0x686;
-			else
+			} else {
 				last_name = 0x600;
+			}
 			if (flxcnt > last_name) {
 				num_misc_names = last_name - 0x500;
-				flxcnt = last_name;
+				flxcnt         = last_name;
 			}
 		}
 		total_msgs = num_text_msgs;
 	}
 	if (msgs.good()) {
 		// Exult msgs. too?
-		first_msg = Read_text_msg_file(msgs, msglist);
+		Text_msg_file_reader reader(msgs);
+		first_msg = reader.get_global_section_strings(msglist);
 		if (first_msg >= 0) {
 			first_msg -= 0x400;
 			if (first_msg < num_text_msgs) {
-				cerr << "Exult msg. # " << first_msg <<
-				     " conflicts with 'text.flx'" << endl;
+				cerr << "Exult msg. # " << first_msg
+					 << " conflicts with 'text.flx'" << endl;
 				first_msg = num_text_msgs;
 			}
 			total_msgs = static_cast<int>(msglist.size() - 0x400);
-		} else
+		} else {
 			first_msg = num_text_msgs;
+		}
 	}
 	item_names.resize(num_item_names);
 	text_msgs.resize(total_msgs);
 	misc_names.resize(num_misc_names);
 	// Hack alert: move SI misc_names around to match those of SS.
-	bool doremap = si && (!expansion || sibeta);
-	if (doremap)
-		flxcnt -= 17;   // Just to be safe.
+	const bool doremap = si && (!expansion || sibeta);
+	if (doremap) {
+		flxcnt -= 17;    // Just to be safe.
+	}
 	int i;
 	for (i = 0; i < flxcnt; i++) {
-		items.seekg(0x80 + i * 8);
-		int itemoffs = Read4(items);
-		if (!itemoffs)
+		items.seek(0x80 + (i * 8));
+		const int itemoffs = items.read4();
+		if (itemoffs == 0) {
 			continue;
-		int itemlen = Read4(items);
-		items.seekg(itemoffs);
-		char *newitem = new char[itemlen];
+		}
+		const int itemlen = items.read4();
+		items.seek(itemoffs);
+		string newitem;
 		items.read(newitem, itemlen);
-		if (i < num_item_names)
-			item_names[i] = newitem;
-		else if (i - num_item_names < num_text_msgs) {
-			if (sibeta && (i - num_item_names) >= 0xd2)
-				text_msgs[i - num_item_names + 1] = newitem;
-			else
-				text_msgs[i - num_item_names] = newitem;
-		} else
-			misc_names[remap_index(doremap,
-			                       i - num_item_names - num_text_msgs,
-			                       sibeta)] = newitem;
-		delete [] newitem;
+		if (i < num_item_names) {
+			item_names[i] = std::move(newitem);
+		} else if (i - num_item_names < num_text_msgs) {
+			if (sibeta && (i - num_item_names) >= 0xd2) {
+				text_msgs[i - num_item_names + 1] = std::move(newitem);
+			} else {
+				text_msgs[i - num_item_names] = std::move(newitem);
+			}
+		} else {
+			const size_t new_index = remap_index(
+					doremap, i - num_item_names - num_text_msgs, sibeta);
+			misc_names[new_index] = std::move(newitem);
+		}
 	}
-	for (i = first_msg; i < total_msgs; i++)
+	for (i = first_msg; i < total_msgs; i++) {
 		text_msgs[i] = msglist[i + 0x400];
+	}
 }
 
-#define SHAPES_SECT  "shapes"
-#define MSGS_SECT    "msgs"
-#define MISC_SECT    "miscnames"
+#define SHAPES_SECT "shapes"
+#define MSGS_SECT   "msgs"
+#define MISC_SECT   "miscnames"
 
 /*
  *  This sets up item names and messages from Exult's new file,
@@ -279,24 +292,28 @@ static void Setup_item_names(
  */
 
 static void Setup_text(
-    istream &txtfile,       // All text.
-    istream &exultmsg
-) {
+		IDataSource& txtfile,    // All text.
+		IDataSource& exultmsg) {
 	// Start by reading from exultmsg
 	vector<string> msglist;
-	int first_msg;
-	first_msg = Read_text_msg_file(exultmsg, msglist);
-	unsigned total_msgs = static_cast<int>(msglist.size() - 0x400);
+	int            first_msg;
+	{
+		Text_msg_file_reader reader(exultmsg);
+		first_msg = reader.get_global_section_strings(msglist);
+	}
+	const unsigned total_msgs = static_cast<int>(msglist.size() - 0x400);
 	if (first_msg >= 0) {
 		first_msg -= 0x400;
 	}
 	text_msgs.resize(total_msgs);
-	for (unsigned i = first_msg; i < total_msgs; i++)
+	for (unsigned i = first_msg; i < total_msgs; i++) {
 		text_msgs[i] = msglist[i + 0x400];
+	}
 	// Now read in textmsg.txt
-	Read_text_msg_file(txtfile, item_names, SHAPES_SECT);
-	Read_text_msg_file(txtfile, text_msgs, MSGS_SECT);
-	Read_text_msg_file(txtfile, misc_names, MISC_SECT);
+	Text_msg_file_reader reader(txtfile);
+	reader.get_section_strings(SHAPES_SECT, item_names);
+	reader.get_section_strings(MSGS_SECT, text_msgs);
+	reader.get_section_strings(MISC_SECT, misc_names);
 }
 
 /*
@@ -305,58 +322,55 @@ static void Setup_text(
 
 void Setup_text(bool si, bool expansion, bool sibeta) {
 	Free_text();
-	bool is_patch = is_system_path_defined("<PATCH>");
+	const bool is_patch = is_system_path_defined("<PATCH>");
 	// Always read from exultmsg.txt
 	// TODO: allow multilingual exultmsg.txt files.
-	istream *exultmsg;
-	if (is_patch && U7exists(PATCH_EXULTMSG)) {
-		auto *exultmsgfile = new ifstream();
-		exultmsg = exultmsgfile;
-		U7open(*exultmsgfile, PATCH_EXULTMSG, true);
-	} else {
-		auto *exultmsgbuf = new stringstream();
-		exultmsg = exultmsgbuf;
-		const char *msgs = BUNDLE_CHECK(BUNDLE_EXULT_FLX, EXULT_FLX);
-		U7object txtobj(msgs, EXULT_FLX_EXULTMSG_TXT);
-		size_t len;
-		auto txt = txtobj.retrieve(len);
-		if (txt && len > 0) {
-			exultmsgbuf->str(string(reinterpret_cast<char*>(txt.get()), len));
+	auto exultmsg = [&]() {
+		if (is_patch && U7exists(PATCH_EXULTMSG)) {
+			return IExultDataSource(PATCH_EXULTMSG, -1);
 		}
-	}
+
+		return IExultDataSource(
+				BUNDLE_CHECK(BUNDLE_EXULT_FLX, EXULT_FLX),
+				EXULT_FLX_EXULTMSG_TXT);
+	}();
 
 	// Exult new-style messages?
 	if (is_patch && U7exists(PATCH_TEXTMSGS)) {
-		ifstream txtfile;
-		U7open(txtfile, PATCH_TEXTMSGS, true);
-		Setup_text(txtfile, *exultmsg);
+		IFileDataSource txtfile(PATCH_TEXTMSGS, true);
+		if (!txtfile.good()) {
+			return;
+		}
+		Setup_text(txtfile, exultmsg);
 	} else if (U7exists(TEXTMSGS)) {
-		ifstream txtfile;
-		U7open(txtfile, TEXTMSGS, true);
-		Setup_text(txtfile, *exultmsg);
+		IFileDataSource txtfile(TEXTMSGS, true);
+		if (!txtfile.good()) {
+			return;
+		}
+		Setup_text(txtfile, exultmsg);
 	} else {
-		ifstream textflx;
-		if (is_patch && U7exists(PATCH_TEXT))
-			U7open(textflx, PATCH_TEXT);
-		else
-			U7open(textflx, TEXT_FLX);
-		Setup_item_names(textflx, *exultmsg, si, expansion, sibeta);
+		IFileDataSource textflx = [&]() {
+			if (is_patch && U7exists(PATCH_TEXT)) {
+				return IFileDataSource(PATCH_TEXT);
+			}
+			return IFileDataSource(TEXT_FLX);
+		}();
+		if (!textflx.good()) {
+			return;
+		}
+		Setup_item_names(textflx, exultmsg, si, expansion, sibeta);
 	}
-	delete exultmsg;
 }
 
 /*
  *  Free memory.
  */
 
-static void Free_text_list(
-    vector<string> &items
-) {
+static void Free_text_list(vector<string>& items) {
 	items.clear();
 }
 
-void Free_text(
-) {
+void Free_text() {
 	Free_text_list(item_names);
 	Free_text_list(text_msgs);
 	Free_text_list(misc_names);
@@ -366,15 +380,15 @@ void Free_text(
  *  Write out new-style Exult text file.
  */
 
-void Write_text_file(
-) {
-	ofstream out;
-
-	U7open(out, PATCH_TEXTMSGS, true);  // (It's a text file.)
-	out << "Exult " << VERSION << " text message file." <<
-	    "  Written by ExultStudio." << endl;
+void Write_text_file() {
+	auto pOut = U7open_out(PATCH_TEXTMSGS, true);    // (It's a text file.)
+	if (!pOut) {
+		return;
+	}
+	auto& out = *pOut;
+	out << "Exult " << VERSION << " text message file."
+		<< "  Written by ExultStudio." << endl;
 	Write_msg_file_section(out, SHAPES_SECT, item_names);
 	Write_msg_file_section(out, MSGS_SECT, text_msgs);
 	Write_msg_file_section(out, MISC_SECT, misc_names);
-	out.close();
 }
