@@ -22,35 +22,39 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+#include "sfxinf.h"
+
+#include "exult_constants.h"
+#include "ignore_unused_variable_warning.h"
 #include "utils.h"
 
 #include <cstdlib>
-#include "exult_constants.h"
-#include "sfxinf.h"
-#include "ignore_unused_variable_warning.h"
 
 using std::istream;
 
 bool SFX_info::read(
-    std::istream &in,   // Input stream.
-    int version,        // Data file version.
-    Exult_Game game     // Loading BG file.
+		std::istream& in,         // Input stream.
+		int           version,    // Data file version.
+		Exult_Game    game        // Loading BG file.
 ) {
 	ignore_unused_variable_warning(game);
 	sfxnum = ReadInt(in);
-	if (sfxnum == -0xff) {  // means delete entry.
+	if (sfxnum == -0xff) {    // means delete entry.
 		set_invalid(true);
 		return true;
 	}
 	if (version >= 2) {
 		chance = ReadInt(in, 100);
-		if (chance < 1 || chance > 100)
+		if (chance < 1 || chance > 100) {
 			chance = 100;
+		}
 		range = ReadInt(in, 1);
-		if (range < 1)
-			range = 1;      // Sensible default.
+		if (range < 1) {
+			range = 1;    // Sensible default.
+		}
 		random = ReadInt(in, 0) != 0;
-		extra = ReadInt(in, -1);
+		extra  = ReadInt(in, -1);
+		volume = ReadInt(in, 100);
 	}
 	return true;
 }
@@ -58,15 +62,15 @@ bool SFX_info::read(
 bool SFX_info::time_to_play() const {
 	return rand() % 100 < chance;
 }
-int SFX_info::get_next_sfx(int &last) const {
+
+int SFX_info::get_next_sfx(int& last) const {
 	if (range > 1) {
-		if (random)
+		if (random) {
 			return sfxnum + (rand() % range);
-		else {
+		} else {
 			last = (last + 1) % range;
 			return sfxnum + last;
 		}
 	}
 	return sfxnum;
 }
-
