@@ -17,69 +17,78 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#	include <config.h>
 #endif
 
-#include <cstring>
-#include <cstdlib>
+#include "txtscroll.h"
 
 #include "common_types.h"
 #include "files/U7file.h"
-#include "gamewin.h"
-#include "shapeid.h"
-#include "txtscroll.h"
 #include "font.h"
 #include "game.h"
+#include "gamewin.h"
+#include "shapeid.h"
 
-#include "SDL_timer.h"
-#include "SDL_events.h"
-#include "SDL_stdinc.h"
-#include "SDL_scancode.h"
+#include <cstdlib>
+#include <cstring>
+
+#ifdef __GNUC__
+#	pragma GCC diagnostic push
+#	pragma GCC diagnostic ignored "-Wold-style-cast"
+#	pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#endif    // __GNUC__
+#include <SDL.h>
+#ifdef __GNUC__
+#	pragma GCC diagnostic pop
+#endif    // __GNUC__
 
 using std::atoi;
+using std::make_unique;
 using std::size_t;
 using std::strchr;
 using std::string;
-using std::strlen;
 using std::strncmp;
 using std::unique_ptr;
-using std::make_unique;
 using std::vector;
 
-TextScroller::TextScroller(const char *archive, int index, Font *fnt, Shape *shp) {
-	font = fnt;
+TextScroller::TextScroller(
+		const char* archive, int index, std::shared_ptr<Font> fnt, Shape* shp) {
+	font   = fnt;
 	shapes = shp;
-	unique_ptr<U7object> txtobj;
-	// Hack to patch MAINSHP_FLX.
-	if (!strncmp(archive, MAINSHP_FLX, sizeof(MAINSHP_FLX) - 1))
-		txtobj = make_unique<U7multiobject>(archive, PATCH_MAINSHP, index);
-	else
-		txtobj = make_unique<U7object>(archive, index);
-	size_t len;
-	const char  CR = '\r';
-	const char  LF = '\n';
+	auto txtobj = [&]() {
+		// Hack to patch MAINSHP_FLX.
+		if (!strncmp(archive, MAINSHP_FLX, sizeof(MAINSHP_FLX) - 1)) {
+			return U7multiobject(archive, PATCH_MAINSHP, index);
+		}
+		return U7multiobject(archive, index);
+	}();
+	size_t     len;
+	const char CR = '\r';
+	const char LF = '\n';
 
-	unique_ptr<unsigned char[]> txt = txtobj->retrieve(len);
+	const unique_ptr<unsigned char[]> txt = txtobj.retrieve(len);
 	if (!txt || len <= 0) {
 		text = new vector<string>();
 		return;
 	}
-	char *ptr = reinterpret_cast<char*>(txt.get());
-	char *end = ptr + len;
+	char* ptr = reinterpret_cast<char*>(txt.get());
+	char* end = ptr + len;
 
 	text = new vector<string>();
 	while (ptr < end) {
-		char *start = ptr;
-		ptr = strchr(ptr, LF);
+		char* start = ptr;
+		ptr         = strchr(ptr, LF);
 		if (ptr) {
-			if (*(ptr - 1) == CR) // It's CR/LF
+			if (*(ptr - 1) == CR) {    // It's CR/LF
 				*(ptr - 1) = 0;
-			else
+			} else {
 				*ptr = 0;
-			text->push_back(string(start));
+			}
+			text->emplace_back(start);
 			ptr += 1;
-		} else
+		} else {
 			break;
+		}
 	}
 }
 
@@ -87,38 +96,38 @@ TextScroller::~TextScroller() {
 	delete text;
 }
 
-int TextScroller::show_line(Game_window *gwin, int left, int right, int y, int index) {
-	Shape_manager *sman = Shape_manager::get_instance();
+int TextScroller::show_line(
+		Game_window* gwin, int left, int right, int y, int index) {
+	Shape_manager* sman = Shape_manager::get_instance();
 
-	//The texts used in the main menu contains backslashed sequences that
-	//indicates the output format of the lines:
-	// \Px   include picture number x (frame nr. of shape passed to constructor)
-	// \C    center line
-	// \L    left aligned to right center line
-	// \R    right aligned to left center line
-	// |     carriage return (stay on same line)
-	// #xxx  display character with number xxx
-	string str = (*text)[index];
-	const char *ptr = str.c_str();
-	char *txt = new char[strlen(ptr) + 1];
+	// The texts used in the main menu contains backslashed sequences that
+	// indicates the output format of the lines:
+	//  \Px   include picture number x (frame nr. of shape passed to constructor)
+	//  \C    center line
+	//  \L    left aligned to right center line
+	//  \R    right aligned to left center line
+	//  |     carriage return (stay on same line)
+	//  #xxx  display character with number xxx
+	const string str = (*text)[index];
+	const char*  ptr = str.c_str();
+	char*        txt = new char[strlen(ptr) + 1];
 
-	char *txtptr = txt;
-	int ypos = y;
-	int vspace = 2; // 2 extra pixels between lines
+	char*     txtptr = txt;
+	int       ypos   = y;
+	const int vspace = 2;    // 2 extra pixels between lines
 	// Align text to the left by default
-	int align = -1;
-	int xpos = left;
-	int center = (right + left) / 2;
-	bool add_line = true;
+	int       align    = -1;
+	int       xpos     = left;
+	const int center   = (right + left) / 2;
+	bool      add_line = true;
 
 	while (*ptr) {
 		if (!strncmp(ptr, "\\P", 2)) {
-			int pix = *(ptr + 2) - '0';
+			const int pix = *(ptr + 2) - '0';
 			ptr += 3;
-			Shape_frame *frame = shapes->get_frame(pix);
+			Shape_frame* frame = shapes->get_frame(pix);
 			if (frame) {
-				sman->paint_shape(center - frame->get_width() / 2,
-				                  ypos, frame);
+				sman->paint_shape(center - frame->get_width() / 2, ypos, frame);
 				ypos += frame->get_height() + vspace;
 			}
 		} else if (!strncmp(ptr, "\\C", 2)) {
@@ -133,99 +142,107 @@ int TextScroller::show_line(Game_window *gwin, int left, int right, int y, int i
 		} else if (*ptr == '|' || *(ptr + 1) == 0) {
 			if (*(ptr + 1) == 0 && *ptr != '|') {
 				*txtptr++ = *ptr;
-				add_line = false;
+				add_line  = false;
 			}
 			*txtptr = 0;
 
-			if (align < 0)
+			if (align < 0) {
 				xpos = center - font->get_text_width(txt);
-			else if (align == 0)
+			} else if (align == 0) {
 				xpos = center - font->get_text_width(txt) / 2;
-			else
+			} else {
 				xpos = center;
-			font->draw_text(gwin->get_win()->get_ib8(),
-			                xpos, ypos, txt);
-			if (*ptr != '|') ypos += font->get_text_height() + vspace;
-			txtptr = txt;   // Go to beginning of string
+			}
+			font->draw_text(gwin->get_win()->get_ib8(), xpos, ypos, txt);
+			if (*ptr != '|') {
+				ypos += font->get_text_height() + vspace;
+			}
+			txtptr = txt;    // Go to beginning of string
 			++ptr;
 		} else if (*ptr == '#') {
 			ptr++;
-			if (*ptr == '#') { // Double hash
+			if (*ptr == '#') {    // Double hash
 				*txtptr++ = *ptr++;
 				continue;
 			}
-			char numerical[4] = {0, 0, 0, 0};
-			char *num = numerical;
-			while (std::isdigit(static_cast<unsigned char>(*ptr)))
+			char  numerical[4] = {0, 0, 0, 0};
+			char* num          = numerical;
+			while (std::isdigit(static_cast<unsigned char>(*ptr))) {
 				*num++ = *ptr++;
+			}
 			*txtptr++ = atoi(numerical);
-		} else
+		} else {
 			*txtptr++ = *ptr++;
+		}
 	}
 
-	delete [] txt;
-	if (add_line)
+	delete[] txt;
+	if (add_line) {
 		ypos += font->get_text_height();
+	}
 	return ypos;
 }
 
-
-bool TextScroller::run(Game_window *gwin) {
+bool TextScroller::run(Game_window* gwin) {
 	gwin->clear_screen();
 	gwin->show(true);
 
-	int topx = (gwin->get_width() - 320) / 2;
-	int topy = (gwin->get_height() - 200) / 2;
-	int endy = topy + 200;
-	uint32 starty = endy;
-	uint32 startline = 0;
-	unsigned int maxlines = text->size();
+	const int          topx      = (gwin->get_width() - 320) / 2;
+	const int          topy      = (gwin->get_height() - 200) / 2;
+	const int          endy      = topy + 200;
+	uint32             starty    = endy;
+	uint32             startline = 0;
+	const unsigned int maxlines  = text->size();
 	if (!maxlines) {
 		gwin->clear_screen();
 		gwin->show(true);
 		return false;
 	}
-	bool looping = true;
-	bool complete = false;
+	bool      looping  = true;
+	bool      complete = false;
 	SDL_Event event;
-	uint32 next_time = SDL_GetTicks() + 200;
-	uint32 incr = 120;
+	uint32    next_time = SDL_GetTicks() + 200;
+	uint32    incr      = 120;
 	//  pal.apply();
 	gwin->get_pal()->apply();
 
 	while (looping) {
-		int ypos = starty;
+		int    ypos    = starty;
 		uint32 curline = startline;
 		gwin->clear_screen();
 		do {
-			if (curline == maxlines)
+			if (curline == maxlines) {
 				break;
+			}
 			ypos = show_line(gwin, topx, topx + 320, ypos, curline++);
-			if (ypos < topy) {  // If this line doesn't appear, don't show it next time
+			if (ypos < topy) {    // If this line doesn't appear, don't show it
+								  // next time
 				++startline;
 				starty = ypos;
 				if (startline >= maxlines) {
-					looping = false;
+					looping  = false;
 					complete = true;
 					break;
 				}
 			}
 		} while (ypos < endy);
-//		pal.apply();
+		//		pal.apply();
 		gwin->show(true);
 		do {
 			// this could be a problem when too many events are produced
 			while (SDL_PollEvent(&event)) {
 				switch (event.type) {
 				case SDL_KEYDOWN:
-					if (event.key.keysym.sym == SDLK_RSHIFT || event.key.keysym.sym == SDLK_LSHIFT)
+					if (event.key.keysym.sym == SDLK_RSHIFT
+						|| event.key.keysym.sym == SDLK_LSHIFT) {
 						incr = 0;
-					else
+					} else {
 						looping = false;
+					}
 					break;
 
 				case SDL_KEYUP:
-					incr = 120;
+					incr      = 120;
 					next_time = SDL_GetTicks();
 					break;
 				case SDL_MOUSEBUTTONUP:
@@ -237,8 +254,9 @@ bool TextScroller::run(Game_window *gwin) {
 			}
 		} while (next_time > SDL_GetTicks());
 		next_time = SDL_GetTicks() + incr;
-		if (!looping)
+		if (!looping) {
 			gwin->get_pal()->fade_out(c_fade_out_time);
+		}
 		starty--;
 	}
 	gwin->clear_screen();
